@@ -30,8 +30,8 @@ LANGUAGES = (
     (_("Arabic"), "ar"),
     (_("Bulgarian"), "bg"),
     (_("Catalan"), "ca"),
-    (_("Chinese simplified"), "szh"),
-    (_("Chinese traditional"), "tzh"),
+    (_("Chinese (Simplified)"), "szh"),
+    (_("Chinese (Traditional)"), "tzh"),
     (_("Croatian"), "hr"),
     (_("Czech"), "cs"),
     (_("Danish"), "da"),
@@ -179,7 +179,7 @@ class YahooHandler(deskbar.interfaces.Module):
         
         try:
             stream = urllib.urlopen(url, proxies=get_proxy())
-        except IOError, msg:
+        except (IOError, EOFError), msg:
             LOGGER.error("Could not open URL %s: %s, %s", url, msg[0], msg[1])
             return
     
@@ -209,6 +209,8 @@ class YahooHandler(deskbar.interfaces.Module):
                                       summary=result_summary,
                                       priority=result_prio))
             
+        matches.append(YahooSearchForMatch(qstring, priority=self.get_priority()))
+            
         LOGGER.debug("Returning yahoo answer for: %s", qstring)
         self._emit_query_ready(qstring, matches)
         
@@ -316,7 +318,7 @@ class YahooSearchForMatch(deskbar.interfaces.Match):
         self.add_action( SearchWithYahooAction(self._term) )
     
     def get_hash(self):
-        return self._term
+        return "yahoo:"+self._term
        
 class YahooSuggestHandler(deskbar.interfaces.Module):
     
@@ -342,7 +344,7 @@ class YahooSuggestHandler(deskbar.interfaces.Module):
         
         try:
             stream = urllib.urlopen(url, proxies=get_proxy())
-        except IOError, msg:
+        except (IOError, EOFError), msg:
             LOGGER.error("Could not open URL %s: %s, %s", url, msg[0], msg[1])
             return
         
